==> alipay-sdk-java-4.39.134.ALL-sources.jar: com/alipay/api/domain/MerchantCardTemplate.java <==
package com.alipay.api.domain;

import java.util.List;

import com.alipay.api.AlipayObject;
import com.alipay.api.internal.mapping.ApiField;
import com.alipay.api.internal.mapping.ApiListField;

/**
 * 商品
 *
 * @author auto create
 * @since 1.0, 2024-07-05 13:59:15
 */
public class MerchantCardTemplate extends AlipayObject {

	private static final long serialVersionUID = 1825173544422817214L;

	/**
	 * 商品归属的小程序appid
	 */
	@ApiField("card_template_app_id")
	private String cardTemplateAppId;

	/**
	 * 支付宝侧商品ID，创建接口不需要传
	 */
	@ApiField("card_template_id")
	private String cardTemplateId;

	/**
	 * 商品名称
	 */
	@ApiField("card_template_name")
	private String cardTemplateName;

	/**
	 * 商品状态，创建接口不需要传
	 */
	@ApiField("card_template_status")
	private String cardTemplateStatus;

	/**
	 * 商品类型
	 */
	@ApiField("card_type")
	private String cardType;

	/**
	 * <a href="https://opendocs.alipay.com/mini/e265db10_alipay.open.app.localitem.allcategory.query?pathHash=186a810a">获取类目接口文档</a>
	 */
	@ApiField("category_id")
	private String categoryId;

	/**
	 * （1）当card_type!=AXF_MERCHANT_PERIOD_PAY,字段image_id_list和image_url_list必须二选一传入，，image_id_list优先级更高
（2）查询返回时该字段为空，返回image_url_list
（3）当card_type=AXF_MERCHANT_PERIOD_PAY，该字段不传，固定为一方小程序的图片url；
	 */
	@ApiListField("image_id_list")
	@ApiField("string")
	private List<String> imageIdList;

	/**
	 * （1）当card_type!=AXF_MERCHANT_PERIOD_PAY,字段image_id_list和image_url_list必须二选一传入，，image_id_list优先级更高
（2）当card_type=AXF_MERCHANT_PERIOD_PAY，该字段不传，固定为一方小程序的图片url；
	 */
	@ApiListField("image_url_list")
	@ApiField("string")
	private List<String> imageUrlList;

	/**
	 * 消息通知appId
	 */
	@ApiField("msg_app_id")
	private String msgAppId;

	/**
	 * 外部商品ID
	 */
	@ApiField("out_card_id")
	private String outCardId;

	/**
	 * 驳回原因
	 */
	@ApiListField("reject_reasons")
	@ApiField("card_reject_reason_info")
	private List<CardRejectReasonInfo> rejectReasons;

	/**
	 * 售卖信息
	 */
	@ApiField("sale_info")
	private CardTemplateSale saleInfo;

	/**
	 * 结算方式
	 */
	@ApiField("settle_type")
	private String settleType;

	/**
	 * 使用信息
	 */
	@ApiField("use_info")
	private CardTemplateUse useInfo;

	public String getCardTemplateAppId() {
		return this.cardTemplateAppId;
	}
	public void setCardTemplateAppId(String cardTemplateAppId) {
		this.cardTemplateAppId = cardTemplateAppId;
	}

	public String getCardTemplateId() {
		return this.cardTemplateId;
	}
	public void setCardTemplateId(String cardTemplateId) {
		this.cardTemplateId = cardTemplateId;
	}

	public String getCardTemplateName() {
		return this.cardTemplateName;
	}
	public void setCardTemplateName(String cardTemplateName) {
		this.cardTemplateName = cardTemplateName;
	}

	public String getCardTemplateStatus() {
		return this.cardTemplateStatus;
	}
	public void setCardTemplateStatus(String cardTemplateStatus) {
		this.cardTemplateStatus = cardTemplateStatus;
	}

	public String getCardType() {
		return this.cardType;
	}
	public void setCardType(String cardType) {
		this.cardType = cardType;
	}

	public String getCategoryId() {
		return this.categoryId;
	}
	public void setCategoryId(String categoryId) {
		this.categoryId = categoryId;
	}

	public List<String> getImageIdList() {
		return this.imageIdList;
	}
	public void setImageIdList(List<String> imageIdList) {
		this.imageIdList = imageIdList;
	}

	public List<String> getImageUrlList() {
		return this.imageUrlList;
	}
	public void setImageUrlList(List<String> imageUrlList) {
		this.imageUrlList = imageUrlList;
	}

	public String getMsgAppId() {
		return this.msgAppId;
	}
	public void setMsgAppId(String msgAppId) {
		this.msgAppId = msgAppId;
	}

	public String getOutCardId() {
		return this.outCardId;
	}
	public void setOutCardId(String outCardId) {
		this.outCardId = outCardId;
	}

	public List<CardRejectReasonInfo> getRejectReasons() {
		return this.rejectReasons;
	}
	public void setRejectReasons(List<CardRejectReasonInfo> rejectReasons) {
		this.rejectReasons = rejectReasons;
	}

	public CardTemplateSale getSaleInfo() {
		return this.saleInfo;
	}
	public void setSaleInfo(CardTemplateSale saleInfo) {
		this.saleInfo = saleInfo;
	}

	public String getSettleType() {
		return this.settleType;
	}
	public void setSettleType(String settleType) {
		this.settleType = settleType;
	}

	public CardTemplateUse getUseInfo() {
		return this.useInfo;
	}
	public void setUseInfo(CardTemplateUse useInfo) {
		this.useInfo = useInfo;
	}

}

==> alipay-sdk-java-4.39.175.ALL-sources.jar: com/alipay/api/domain/MerchantCardTemplate.java <==
package com.alipay.api.domain;

import java.util.List;

import com.alipay.api.AlipayObject;
import com.alipay.api.internal.mapping.ApiField;
import com.alipay.api.internal.mapping.ApiListField;

/**
 * 卡
 *
 * @author auto create
 * @since 1.0, 2024-08-12 20:36:50
 */
public class MerchantCardTemplate extends AlipayObject {

	private static final long serialVersionUID = 7221566452216312323L;

	/**
	 * 卡归属的小程序appid
	 */
	@ApiField("card_template_app_id")
	private String cardTemplateAppId;

	/**
	 * 支付宝侧卡ID，创建接口不需要传
	 */
	@ApiField("card_template_id")
	private String cardTemplateId;

	/**
	 * 卡名称（当card_type=AXF_MONEY_CARD时，查询会返回）
	 */
	@ApiField("card_template_name")
	private String cardTemplateName;

	/**
	 * 卡状态，创建接口不需要传
	 */
	@ApiField("card_template_status")
	private String cardTemplateStatus;

	/**
	 * 卡类型
	 */
	@ApiField("card_type")
	private String cardType;

	/**
	 * <a href="https://opendocs.alipay.com/mini/e265db10_alipay.open.app.localitem.allcategory.query?pathHash=186a810a">获取类目接口文档</a>
	 */
	@ApiField("category_id")
	private String categoryId;

	/**
	 * 客服电话
	 */
	@ApiField("hotline")
	private String hotline;

	/**
	 * （1）当card_type不等于AXF_MERCHANT_PERIOD_PAY或AXF_PERIOD_PAY_INDIRECT时,字段image_id_list和image_url_list必须二选一传入，image_id_list优先级更高
（2）查询返回时该字段为空，返回image_url_list
（3）当card_type=AXF_MERCHANT_PERIOD_PAY或AXF_PERIOD_PAY_INDIRECT或AXF_MONEY_CARD时，该字段不传，固定为一方小程序的图片url；
	 */
	@ApiListField("image_id_list")
	@ApiField("string")
	private List<String> imageIdList;

	/**
	 * （1）当card_type不等于AXF_MERCHANT_PERIOD_PAY或AXF_PERIOD_PAY_INDIRECT时,字段image_id_list和image_url_list必须二选一传入，image_id_list优先级更高
（2）当card_type=AXF_MERCHANT_PERIOD_PAY或AXF_PERIOD_PAY_INDIRECT或AXF_MONEY_CARD时，该字段不传，固定为一方小程序的图片url；
	 */
	@ApiListField("image_url_list")
	@ApiField("string")
	private List<String> imageUrlList;

	/**
	 * 金额卡的必要参数。其他卡类型无需传入
	 */
	@ApiField("money_card_info")
	private MoneyCardInfo moneyCardInfo;

	/**
	 * 消息通知appId
	 */
	@ApiField("msg_app_id")
	private String msgAppId;

	/**
	 * 外部卡ID
	 */
	@ApiField("out_card_id")
	private String outCardId;

	/**
	 * 驳回原因
	 */
	@ApiListField("reject_reasons")
	@ApiField("card_reject_reason_info")
	private List<CardRejectReasonInfo> rejectReasons;

	/**
	 * 售卖信息
	 */
	@ApiField("sale_info")
	private CardTemplateSale saleInfo;

	/**
	 * 结算方式
	 */
	@ApiField("settle_type")
	private String settleType;

	/**
	 * 使用信息
	 */
	@ApiField("use_info")
	private CardTemplateUse useInfo;

	public String getCardTemplateAppId() {
		return this.cardTemplateAppId;
	}
	public void setCardTemplateAppId(String cardTemplateAppId) {
		this.cardTemplateAppId = cardTemplateAppId;
	}

	public String getCardTemplateId() {
		return this.cardTemplateId;
	}
	public void setCardTemplateId(String cardTemplateId) {
		this.cardTemplateId = cardTemplateId;
	}

	public String getCardTemplateName() {
		return this.cardTemplateName;
	}
	public void setCardTemplateName(String cardTemplateName) {
		this.cardTemplateName = cardTemplateName;
	}

	public String getCardTemplateStatus() {
		return this.cardTemplateStatus;
	}
	public void setCardTemplateStatus(String cardTemplateStatus) {
		this.cardTemplateStatus = cardTemplateStatus;
	}

	public String getCardType() {
		return this.cardType;
	}
	public void setCardType(String cardType) {
		this.cardType = cardType;
	}

	public String getCategoryId() {
		return this.categoryId;
	}
	public void setCategoryId(String categoryId) {
		this.categoryId = categoryId;
	}

	public String getHotline() {
		return this.hotline;
	}
	public void setHotline(String hotline) {
		this.hotline = hotline;
	}

	public List<String> getImageIdList() {
		return this.imageIdList;
	}
	public void setImageIdList(List<String> imageIdList) {
		this.imageIdList = imageIdList;
	}

	public List<String> getImageUrlList() {
		return this.imageUrlList;
	}
	public void setImageUrlList(List<String> imageUrlList) {
		this.imageUrlList = imageUrlList;
	}

	public MoneyCardInfo getMoneyCardInfo() {
		return this.moneyCardInfo;
	}
	public void setMoneyCardInfo(MoneyCardInfo moneyCardInfo) {
		this.moneyCardInfo = moneyCardInfo;
	}

	public String getMsgAppId() {
		return this.msgAppId;
	}
	public void setMsgAppId(String msgAppId) {
		this.msgAppId = msgAppId;
	}

	public String getOutCardId() {
		return this.outCardId;
	}
	public void setOutCardId(String outCardId) {
		this.outCardId = outCardId;
	}

	public List<CardRejectReasonInfo> getRejectReasons() {
		return this.rejectReasons;
	}
	public void setRejectReasons(List<CardRejectReasonInfo> rejectReasons) {
		this.rejectReasons = rejectReasons;
	}

	public CardTemplateSale getSaleInfo() {
		return this.saleInfo;
	}
	public void setSaleInfo(CardTemplateSale saleInfo) {
		this.saleInfo = saleInfo;
	}

	public String getSettleType() {
		return this.settleType;
	}
	public void setSettleType(String settleType) {
		this.settleType = settleType;
	}

	public CardTemplateUse getUseInfo() {
		return this.useInfo;
	}
	public void setUseInfo(CardTemplateUse useInfo) {
		this.useInfo = useInfo;
	}

}
